@@ -20,7 +20,6 @@
 #include <QDebug>
 #include <KLocalizedString>
 #include <KScoreDialog>
-#include <KHighscore>
 #include <KStandardGameAction>
 #include <QStatusBar>
 #include <QAction>
@@ -66,7 +65,6 @@ void KSquaresWindow::initObject()
     gameNew();
 }
 
-//void KSquaresWindow::configureHighscores() {KExtHighscore::configure(this);}
 void KSquaresWindow::showHighscores()
 {
     KScoreDialog ksdialog(KScoreDialog::Name, this);
